==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Sections/language/lang-turkish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_PRINTER","Yazdrlabilir Sayfa");
define("_PREVIOUS","nceki Sayfa");
define("_NEXT","Sonraki Sayfa");
define("_COMESFROM","Bu haberin geldigi yer:");
define("_THEURL","Bu haber icin adres:");
define("_SECWELCOME","zel Blmlere Hogeldiniz:");
define("_YOUCANFIND","Buradan ana sayfada yaynlanmam ilgin yazlara ulaabilirsiniz.");
define("_THISISSEC","Blm:");
define("_FOLLOWINGART","Bu blmde yaynlanm yazlara aadan ulaabilirsiniz.");
define("_SECRETURN","Blmler ndeksine Dn");
define("_TOTALWORDS","kelime");
define("_BACKTO","Geri Dn:");
define("_SECINDEX","Blmler ndeksi");
define("_PAGE","Sayfa");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Sections/language/lang-turkish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_PRINTER","Yazdrlabilir Sayfa");
define("_PREVIOUS","nceki Sayfa");
define("_NEXT","Sonraki Sayfa");
define("_COMESFROM","Bu haberin geldigi yer:");
define("_THEURL","Bu haber icin adres:");
define("_SECWELCOME","zel Blmlere Hogeldiniz:");
define("_YOUCANFIND","Buradan ana sayfada yaynlanmam ilgin yazlara ulaabilirsiniz.");
define("_THISISSEC","Blm:");
define("_FOLLOWINGART","Bu blmde yaynlanm yazlara aadan ulaabilirsiniz.");
define("_SECRETURN","Blmler ndeksine Dn");
define("_TOTALWORDS","kelime");
define("_BACKTO","Geri Dn:");
define("_SECINDEX","Blmler ndeksi");
define("_PAGE","Sayfa");

?>
